sipua — sipua documentation

# sipua

The `sipua` project provides a library for writing SIP user agents in Python.

## API Reference

class sipua.TransportLayer(*, message_handler: Callable[[Message], Awaitable[None]])

  SIP transport layer.

  async close() → None

    Close the transport layer.

  async listen(address: TransportAddress) → None

    Start listening on the given transport address.

  async send_message(message: Message) → bool

    Send the given message and return whether the selected transport is reliable.